# NEP

Node Primitives (NEP) is a user-friendly, reusable and cross-platform communication framework for building robot software architectures.


[Official website](https://enriquecoronadozu.github.io/Nep/)
